from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ApplyCls:
	"""Apply commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("apply", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:PMETer:LEVel:CORRection:APPLy \n
		Snippet: driver.applications.k18AmplifierEt.sense.pmeter.level.correction.apply.set(state = False) \n
		Sets and queries the toggle to apply the auto level correction. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 ON | 1
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:PMETer:LEVel:CORRection:APPLy {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:PMETer:LEVel:CORRection:APPLy \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.sense.pmeter.level.correction.apply.get() \n
		Sets and queries the toggle to apply the auto level correction. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 ON | 1"""
		response = self._core.io.query_str(f'SENSe:PMETer:LEVel:CORRection:APPLy?')
		return Conversions.str_to_bool(response)
